==> bootstrap-10.14.1.tgz: package/Shop/Shop.esm.js <==
import * as React from 'react';
import { StyledIconBase } from '@styled-icons/styled-icon';
export const Shop = /*#__PURE__*/React.forwardRef((props, ref) => {
  const attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(StyledIconBase, Object.assign({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 16 16"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    fillRule: "evenodd",
    d: "M0 15.5a.5.5 0 01.5-.5h15a.5.5 0 010 1H.5a.5.5 0 01-.5-.5zM3.12 1.175A.5.5 0 013.5 1h9a.5.5 0 01.38.175l2.759 3.219A1.5 1.5 0 0116 5.37v.13h-1v-.13a.5.5 0 00-.12-.325L12.27 2H3.73L1.12 5.045A.5.5 0 001 5.37v.13H0v-.13a1.5 1.5 0 01.361-.976l2.76-3.22z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M2.375 6.875c.76 0 1.375-.616 1.375-1.375h1a1.375 1.375 0 002.75 0h1a1.375 1.375 0 002.75 0h1a1.375 1.375 0 102.75 0h1a2.375 2.375 0 01-4.25 1.458 2.371 2.371 0 01-1.875.917A2.37 2.37 0 018 6.958a2.37 2.37 0 01-1.875.917 2.37 2.37 0 01-1.875-.917A2.375 2.375 0 010 5.5h1c0 .76.616 1.375 1.375 1.375z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M4.75 5.5a.5.5 0 11-1 0 .5.5 0 011 0zm3.75 0a.5.5 0 11-1 0 .5.5 0 011 0zm3.75 0a.5.5 0 11-1 0 .5.5 0 011 0z"
  }), /*#__PURE__*/React.createElement("path", {
    fillRule: "evenodd",
    d: "M2 7.846V7H1v.437c.291.207.632.35 1 .409zm-1 .737c.311.14.647.232 1 .271V15H1V8.583zm13 .271a3.354 3.354 0 001-.27V15h-1V8.854zm1-1.417c-.291.207-.632.35-1 .409V7h1v.437zM3 9.5a.5.5 0 01.5-.5h4a.5.5 0 01.5.5V15H7v-5H4v5H3V9.5zm6 0a.5.5 0 01.5-.5h3a.5.5 0 01.5.5v4a.5.5 0 01-.5.5h-3a.5.5 0 01-.5-.5v-4zm1 .5v3h2v-3h-2z"
  }));
});
Shop.displayName = 'Shop';
export const ShopDimensions = {
  height: 16,
  width: 16
};

==> bootstrap-10.15.1.tgz: package/Shop/Shop.esm.js <==
import _extends from "@babel/runtime/helpers/extends";
import * as React from 'react';
import { StyledIconBase } from '@styled-icons/styled-icon';
export var Shop = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(StyledIconBase, _extends({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 16 16"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    fillRule: "evenodd",
    d: "M0 15.5a.5.5 0 01.5-.5h15a.5.5 0 010 1H.5a.5.5 0 01-.5-.5zM3.12 1.175A.5.5 0 013.5 1h9a.5.5 0 01.38.175l2.759 3.219A1.5 1.5 0 0116 5.37v.13h-1v-.13a.5.5 0 00-.12-.325L12.27 2H3.73L1.12 5.045A.5.5 0 001 5.37v.13H0v-.13a1.5 1.5 0 01.361-.976l2.76-3.22z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M2.375 6.875c.76 0 1.375-.616 1.375-1.375h1a1.375 1.375 0 002.75 0h1a1.375 1.375 0 002.75 0h1a1.375 1.375 0 102.75 0h1a2.375 2.375 0 01-4.25 1.458 2.371 2.371 0 01-1.875.917A2.37 2.37 0 018 6.958a2.37 2.37 0 01-1.875.917 2.37 2.37 0 01-1.875-.917A2.375 2.375 0 010 5.5h1c0 .76.616 1.375 1.375 1.375z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M4.75 5.5a.5.5 0 11-1 0 .5.5 0 011 0zm3.75 0a.5.5 0 11-1 0 .5.5 0 011 0zm3.75 0a.5.5 0 11-1 0 .5.5 0 011 0z"
  }), /*#__PURE__*/React.createElement("path", {
    fillRule: "evenodd",
    d: "M2 7.846V7H1v.437c.291.207.632.35 1 .409zm-1 .737c.311.14.647.232 1 .271V15H1V8.583zm13 .271a3.354 3.354 0 001-.27V15h-1V8.854zm1-1.417c-.291.207-.632.35-1 .409V7h1v.437zM3 9.5a.5.5 0 01.5-.5h4a.5.5 0 01.5.5V15H7v-5H4v5H3V9.5zm6 0a.5.5 0 01.5-.5h3a.5.5 0 01.5.5v4a.5.5 0 01-.5.5h-3a.5.5 0 01-.5-.5v-4zm1 .5v3h2v-3h-2z"
  }));
});
Shop.displayName = 'Shop';
export var ShopDimensions = {
  height: 16,
  width: 16
};
